@@ -26,7 +26,7 @@ def run(event, context):
     puml            = event['puml']
     puml            = puml.replace('&lt;', '<').replace('&gt;', '>')
     (fd, tmp_file)  = tempfile.mkstemp('png)')
-    puml_to_png     = Lambdas('utils.puml_to_png').invoke
+    puml_to_png     = Lambda('utils.puml_to_png').invoke
     result          = puml_to_png({"puml": puml })
 
 
